@@ -48,6 +48,19 @@ def get_STATE_machine(self, field='state', machine=None):
     return machine
 
 
+def get_STATE_display(self, field='state', machine=None):
+    """
+    Gets the description of the current state from the machine
+    """
+
+    if machine is None:
+        return None
+    assert isinstance(machine, StateMachineMeta), "Machine must be a valid StateMachine"
+
+    si = machine.get_state(getattr(self, field))
+    return si.description
+
+
 def get_STATE_info(self, field='state', machine=None):
     """
     Gets the state definition from the machine
@@ -193,10 +206,7 @@ def get_STATE_info(self, field='state', machine=None):
                 if _state_log_model:
                     transition_log.make_transition('fail')
 
-                # Print original traceback for debugging
-                import traceback
-                traceback.print_exc()
-                raise e
+                raise
             else:
                 if _state_log_model:
                     transition_log.make_transition('complete')
