@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import patterns, include, url
+from .compat import patterns, include, url
 
 from django.contrib import admin
 admin.autodiscover()
